﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Diagnostics;
using System.IO;
using System.ServiceModel;
using System.Text;
using HeuristicLab.Services.Hive.DataAccess;

namespace HeuristicLab.Services.Hive {
  public class HiveOperationContext : IExtension<OperationContext> {
    public static HiveOperationContext Current {
      get {
        var context = OperationContext.Current.Extensions.Find<HiveOperationContext>();
        if (context == null) {
          context = new HiveOperationContext();
          OperationContext.Current.Extensions.Add(context);
        }
        return context;
      }
    }

    public HiveDataContext DataContext { get; private set; }

    public void Attach(OperationContext owner) {
      DataContext = HiveDao.CreateContext();
      //DataContext.Log = new DebugWriter();
    }

    public void Detach(OperationContext owner) {
      // nothing
    }
  }

  internal class DebugWriter : TextWriter {
    public override Encoding Encoding {
      get { return Encoding.UTF8; }
    }

    public override void Write(char value) {
      Debug.Write(value);
    }

    public override void Write(string value) {
      Debug.Write(value);
    }

    public override void WriteLine(string value) {
      Debug.WriteLine(value);
    }
  }
}
